@@ -293,11 +293,7 @@ class CLI(object):
         """
         Create a new stack. 
         """
-        mode = self._parse_deploy_arg('mode', args, default='local')
-        conf = self._parse_deploy_arg('conf', args, default='default')
         payload = { 'payload' : json.dumps(stack_description),
-                    'mode' : mode, 
-                    'conf' : conf,
                     'key' : private_key }
         try:
             res = requests.post(self.ferry_server + '/create', data=payload)
@@ -318,7 +314,7 @@ class CLI(object):
         for app in json_data.keys():
             authors.append(json_data[app]['author'])
             versions.append(json_data[app]['version'])
-            descriptions.append(json_data[app]['description'])            
+            descriptions.append(json_data[app]['short'])            
 
         t = PrettyTable()
         t.add_column("App", json_data.keys())
