@@ -18,7 +18,6 @@ import os
 import stat
 import logging
 from string import Template
-from ferry.docker.fabric import DockerFabric
 
 """
 Create Gluster configurations and apply them to a set of instances
@@ -76,28 +75,37 @@ class GlusterInitializer(object):
     def generate_config_dir(self, uuid):
         return 'gluster_' + str(uuid)
 
-    """
-    Get the ports necessary for Gluster. 
-    """
-    def get_necessary_ports(self, num_instances):
+    def get_public_ports(self, num_instances):
+        """
+        Ports to expose to the outside world. 
+        """
         return []
 
-    """
-    Get the internal ports. 
-    """
-    def get_exposed_ports(self, num_instances):
-        ports = []
-        
-        ports.append(GlusterConfig.MANAGEMENT_PORT)
-        for i in range(0, num_instances):
-            ports.append(GlusterConfig.BRICK_PORT + i)
+    def get_internal_ports(self, num_instances):
+        """
+        Ports needed for communication within the network. 
+        This is usually used for internal IPC.
+        """
+        return ["0-65535"]
 
+    def get_working_ports(self, num_instances):
+        """
+        Ports necessary to get things working. 
+        """
+        ports = []
+        ports.append(str(GlusterConfig.PORT_MAPPER))
+        ports.append(str(GlusterConfig.NFS_PORT1))
+        ports.append(str(GlusterConfig.NFS_PORT2))
+        ports.append(str(GlusterConfig.NFS_PORT3))
+        ports.append(str(GlusterConfig.MANAGEMENT_PORT))
+        for i in range(0, num_instances):
+            ports.append(str(GlusterConfig.BRICK_PORT + i))
         return ports
 
-    """
-    Get total number of instances.
-    """
     def get_total_instances(self, num_instances, layers):
+        """
+        Get total number of instances.
+        """
         instances = []
 
         for i in range(num_instances):
@@ -199,6 +207,10 @@ class GlusterConfig(object):
     log_directory = '/service/logs/'
     config_directory = '/service/conf/gluster/'
 
+    PORT_MAPPER = 111
+    NFS_PORT1 = 34865
+    NFS_PORT2 = 34866
+    NFS_PORT3 = 34867
     BRICK_PORT = 24009
     MANAGEMENT_PORT = 24007
 
