@@ -288,10 +288,15 @@ class DockerManager(object):
         """
         Inspect a running stack. 
         """
-        json_reply = {}
+        json_reply = { 'uuid' : stack_uuid,
+                       'status' : 'stack' }
 
         # Get the collection of all backends and connector UUIDS.
         cluster = self.cluster_collection.find_one( {'uuid': stack_uuid} )
+        json_reply['key'] = cluster['key']
+        json_reply['base'] = cluster['base']
+        json_reply['ts'] = str(cluster['ts'])
+        json_reply['output'] = cluster['output']
 
         connector_uuids = []
         if cluster and 'connectors' in cluster:
@@ -323,9 +328,7 @@ class DockerManager(object):
             json_reply['compute'].append(self._get_inspect_info(uuid))
 
         # Now append some snapshot info. 
-        json_reply['snapshots'] = self._get_snapshot_info(stack_uuid)
-           
-        json_reply['status'] = 'stack'
+        json_reply['snapshots'] = self._get_snapshot_info(stack_uuid)    
         return json.dumps(json_reply, 
                           sort_keys=True,
                           indent=2,
@@ -355,36 +358,69 @@ class DockerManager(object):
                 apps.add(c)
         return apps
 
-    def _query_application(self, directory):
+    def _query_application(self, directory, app):
         apps = {}
         app_files = self._list_applications(directory)
         for f in app_files:
             file_path = directory + '/' + f
             n, e = f.split(".")
             content = None
-            if e == 'json':
-                json_string = self._read_file_arg(file_path)
-                content = json.loads(json_string)
-            elif e == 'yaml' or e == 'yml':
-                yaml_file = open(file_path, 'r')
-                content = yaml.load(yaml_file)
 
-            if content and 'metadata' in content:
-                apps[n] = { 'author' : content['metadata']['author'],
-                            'version': content['metadata']['version'],
-                            'description': content['metadata']['description'][:21] + "..." }
-            else:
-                apps[n] = { 'author' : "Unknown",
-                            'version': "Unknown",
-                            'description': "Unknown" }
+            # Check if there is a filter or not. 
+            if not app or app == n:
+                if e == 'json':
+                    json_string = self._read_file_arg(file_path)
+                    content = json.loads(json_string)
+                elif e == 'yaml' or e == 'yml':
+                    yaml_file = open(file_path, 'r')
+                    content = yaml.load(yaml_file)
+
+                if content and 'metadata' in content:
+                    apps[n] = { 'name' : n,
+                                'file' : file_path, 
+                                'tags' : content['metadata']['tags'],
+                                'author' : content['metadata']['author'],
+                                'version': content['metadata']['version'],
+                                'url': content['metadata']['url'],
+                                'short' : content['metadata']['description'][:21] + "...",
+                                'description': content['metadata']['description'],
+                                'plan' : { 'params' : content['params'],
+                                           'backend' : content['backend'],
+                                           'connectors' : content['connectors'] }}
+
+                    # Check if this application template has any
+                    # user questions. 
+                    if 'questions' in content:
+                        apps[n]['questions'] = content['questions']
+                    else:
+                        apps[n]['questions'] = []
+
+                    # See if the application author has provided an icon name.
+                    # This is completely optional. 
+                    if 'icon' in content['metadata']:
+                        apps[n]['icon'] = content['metadata']['icon']
+                    else:
+                        apps[n]['icon'] = ""
+                else:
+                    apps[n] = { 'name' : n,
+                                'file' : '', 
+                                'tags' : [], 
+                                'author' : "Unknown",
+                                'version': "Unknown",
+                                'url': "",
+                                'short' : "", 
+                                'icon': "",
+                                'description': "",
+                                'questions': [],
+                                'plan' : {} }
         return apps
     
-    def query_applications(self):
+    def query_applications(self, app=None):
         """
         Get list of installed applications.
         """
-        builtin = self._query_application(ferry.install.DEFAULT_BUILTIN_APPS)
-        installed = self._query_application(ferry.install.DEFAULT_FERRY_APPS)
+        builtin = self._query_application(ferry.install.DEFAULT_BUILTIN_APPS, app)
+        installed = self._query_application(ferry.install.DEFAULT_FERRY_APPS, app)
         return json.dumps(dict(builtin.items() + installed.items()))
         
     def query_snapshots(self, constraints=None):
@@ -617,11 +653,11 @@ class DockerManager(object):
             new_log_dir = self._new_log_dir(service_uuid, t, i, replace=replace)
             dir_info = { new_log_dir : log_dir }
 
-            # Only use a data directory mapping if we're not
-            # using BTRFS (this is to get around the xattr problem). 
-            if self.docker.get_fs_type() != "btrfs":
-                new_data_dir = self._new_data_dir(service_uuid, t, i)
-                dir_info[new_data_dir] = container_dir
+            # Create an external data directory so that we can
+            # easily restart containers without losing data. Also
+            # helps with overall performance. 
+            new_data_dir = self._new_data_dir(service_uuid, t, i)
+            dir_info[new_data_dir] = container_dir
 
             container_info = {'image':instance_type,
                               'type':t, 
@@ -815,7 +851,7 @@ class DockerManager(object):
         """
         return self._new_stack_uuid()
 
-    def register_stack(self, backends, connectors, base, cluster_uuid, status, key=None, new_stack=True):
+    def register_stack(self, backends, connectors, base, cluster_uuid, status, output=None, key=None, new_stack=True):
         """
         Register the set of services under a single cluster identifier. 
         """
@@ -828,6 +864,7 @@ class DockerManager(object):
                     'backends' : backends,
                     'connectors' : connectors, 
                     'status': status,
+                    'output' : output, 
                     'key' : key, 
                     'ts':ts }
 
