@@ -24,9 +24,13 @@ import Queue
 import threading2
 import time
 
+from flask.ext.cors import CORS
+
 # Initialize Flask
 app = Flask(__name__)
 
+CORS(app, resources=r'/*', headers='Content-Type')
+
 # Initialize the storage driver
 installer = Installer()
 docker = DockerManager()
@@ -487,6 +491,7 @@ def _allocate_new_worker(uuid, payload):
                                   key = key_name,
                                   cluster_uuid = uuid, 
                                   status='running', 
+                                  output = output,
                                   new_stack=False)
             reply['text'] = str(uuid)
             reply['msgs'] = output
@@ -536,6 +541,7 @@ def _allocate_stopped_worker(payload):
                               base = stack['base'],
                               cluster_uuid = uuid,
                               status='running', 
+                              output = output,
                               key = stack['key'],
                               new_stack = False)
         return json.dumps({'status' : 'ok',
@@ -582,6 +588,7 @@ def _allocate_snapshot_worker(uuid, payload):
                               base = payload['_file'],
                               cluster_uuid = uuid,
                               status='running', 
+                              output = output,
                               key = key_name,
                               new_stack = True)
         return json.dumps({'status' : 'ok',
@@ -658,9 +665,8 @@ def allocate_stack():
     Create some new storage infrastructure
     """
     payload = json.loads(request.form['payload'])
-    mode = request.form['mode']
-    conf = request.form['conf']
     key_name = request.form['key']
+    logging.warning("PAYLOAD: " + str(payload))
 
     # Check whether the user wants to start from fresh or
     # start with a snapshot.
@@ -704,7 +710,12 @@ def apps():
     """
     Get list of installed applications.
     """
-    return docker.query_applications()
+    if 'app' in request.args:
+        app = request.args['app']
+    else:
+        app = None
+
+    return docker.query_applications(app)
 
 @app.route('/stack', methods=['GET'])
 def inspect():
@@ -717,7 +728,6 @@ def inspect():
         # This is an active application stack. 
         return docker.inspect_stack(uuid)
     elif docker.is_installed(uuid):
-        # This is the name of an installed application.
         return docker.inspect_installed(uuid)
     else:
         # Try to see if this is an active service.
